@@ -27,10 +27,10 @@
 /*
  * This file contains modifications Copyright 2006-2011 J. Schilling
  *
- * @(#)admin.c	1.58 11/08/22 J. Schilling
+ * @(#)admin.c	1.62 11/09/03 J. Schilling
  */
 #if defined(sun)
-#pragma ident "@(#)admin.c 1.58 11/08/22 J. Schilling"
+#pragma ident "@(#)admin.c 1.62 11/09/03 J. Schilling"
 #endif
 /*
  * @(#)admin.c 1.39 06/12/12
@@ -141,6 +141,7 @@ static struct	utsname	un;
 static char	*uuname;
 static int 	Encoded = 0;
 static off_t	Encodeflag_offset;	/* offset in file where encoded flag is stored */
+static off_t	Checksum_offset;	/* offset in file where g-file hash is stored */
 
 	int	main __PR((int argc, char **argv));
 static	void	admin __PR((char *afile));
@@ -753,19 +754,21 @@ char	*afile;
 		fatal(gettext("cannot create lock file (cm4)"));
 
 	if (fexists) { /* modifying */
+		int	cklen = 8;
 
 		sinit(&gpkt,afile,1);	/* init pkt & open s-file */
+
+		if (gpkt.p_flags & PF_V6)
+			cklen = 15;
 	
 		/* Modify checksum if corrupted */
 
-	        if ((int) strlen(gpkt.p_line) > 8 && gpkt.p_line[0] == '\001'
-		         && gpkt.p_line[1] == '\150' ) 
-		{
-			gpkt.p_line[7] = '\012';
-		   	gpkt.p_line[8] = '\000';
-	
+		if ((int) strlen(gpkt.p_line) > cklen &&
+		    gpkt.p_line[0] == '\001' &&
+		    gpkt.p_line[1] == '\150') {
+			gpkt.p_line[cklen-1] = '\012';
+			gpkt.p_line[cklen]   = '\000';
 		}
-
 	}
 
 
@@ -895,6 +898,10 @@ char	*afile;
 				fatal(gettext("invalid MRs (de9)"));
 			putmrs(&gpkt);
 		}
+		if (gpkt.p_flags & PF_V6) {
+			Checksum_offset = ftell(Xiop);
+			sidext_ba(&gpkt, &dt);	/* Will not write "dt" entry. */
+		}
 
 		/*
 		Enter comment line for `chghist'
@@ -1311,8 +1318,17 @@ char	*afile;
 		*/
 		sprintf(line,"%c%c %d\n",CTLCHAR,END,1);
 		putline(&gpkt,line);
-	}
-	else {
+		if (gpkt.p_flags & PF_V6 && gpkt.p_ghash != 0) {
+			fseek(Xiop, Checksum_offset, SEEK_SET);
+			fprintf(Xiop, "%c%c s %5.5d\n",
+				CTLCHAR, SIDEXTENS, gpkt.p_ghash);
+			gpkt.p_nhash -= 5 * '0';
+			sprintf(line, "%5.5d", gpkt.p_ghash);
+			q = (signed char *) line;
+			while (*q)
+				gpkt.p_nhash += *q++;
+		}
+	} else {
 		/*
 		Indicate that EOF at this point is ok, and
 		flush rest of (old) s-file to x-file.
@@ -1395,6 +1411,7 @@ struct	packet	*pkt;		/* struct paket for output	*/
 	off_t	ibase = 0;	/* Ifile off from last read operation	*/
 	off_t	ioff = 0;	/* Ifile offset past last newline	*/
 	off_t	soff = ftell(Xiop); /* Ofile (s. file) base offset	*/
+	unsigned int sum = 0;
 
 	/*
 	 * This gives the illusion that a zero-length file ends
@@ -1413,6 +1430,7 @@ struct	packet	*pkt;		/* struct paket for output	*/
 	 * of the buffer.
 	 */
 	while ((idx = fread(line, 1, sizeof (line) - 1, inptr)) > 0) {
+		sum += usum(line, idx);
 		lastline = line;
 		if (lastchar == '\n' && line[0] == CTLCHAR) {
 			chkflags |= CK_CTLCHAR;
@@ -1468,11 +1486,12 @@ struct	packet	*pkt;		/* struct paket for output	*/
 				}
 			}
 		}
-		if (check_id) {
-			(void)chkid(line, flag_p['i'-'a'], flag_p);
-		}
 		line[idx] = '\0';
 		putline(pkt, lastline);
+
+		if (check_id && Did_id == 0) {
+			(void)chkid(line, flag_p['i'-'a'], flag_p);
+		}
 		ibase += idx;
 	}
 #else	/* !RECORD_IO */
@@ -1507,6 +1526,7 @@ struct	packet	*pkt;		/* struct paket for output	*/
 		 }
 	      } else {
 		 if (line[idx] == '\0') {
+		    sum += usum(line, idx);
 		    search_on = 1;
 		    lastchar = line[idx-1];
 		    if (lastchar == '\n') {
@@ -1518,13 +1538,14 @@ struct	packet	*pkt;		/* struct paket for output	*/
 		 }
 	      }
 	   }   
-	   if (check_id) {
+	   if (check_id && Did_id == 0) {
 	      (void)chkid(line, flag_p['i'-'a'], flag_p);
 	   }
 	   putline(pkt, line);
 	   (void)memset(line, '\377', sizeof (line));
 	}
 #endif	/* !RECORD_IO */
+	pkt->p_ghash = sum & 0xFFFF;
 	if (lastchar != '\n')
 		chkflags |= CK_NONL;
 	pkt->p_props |= chkflags;
@@ -1546,7 +1567,9 @@ struct	packet	*pkt;		/* struct paket for output	*/
 			}
 			putchr(pkt, '\n');
 			fprintf(stderr, gettext(
-			    "WARNING [%s]: No newline at end of file (ad31)\n"),
+			    "WARNING [%s%s%s]: No newline at end of file (ad31)\n"),
+				dir_name,
+				*dir_name?"/":"",
 				file);
 			return (nline);
 		}
@@ -1570,7 +1593,9 @@ warnctl(file, nline)
 {
 	fprintf(stderr,
 		gettext(
-		"WARNING [%s]: line %jd begins with ^A\n"),
+		"WARNING [%s%s%s]: line %jd begins with ^A\n"),
+		dir_name,
+		*dir_name?"/":"",
 		file, (intmax_t)nline);
 }
  
