@@ -27,10 +27,10 @@
 /*
  * This file contains modifications Copyright 2006-2011 J. Schilling
  *
- * @(#)delta.c	1.43 11/08/22 J. Schilling
+ * @(#)delta.c	1.45 11/09/03 J. Schilling
  */
 #if defined(sun)
-#pragma ident "@(#)delta.c 1.43 11/08/22 J. Schilling"
+#pragma ident "@(#)delta.c 1.45 11/09/03 J. Schilling"
 #endif
 /*
  * @(#)delta.c 1.40 06/12/12
@@ -309,6 +309,7 @@ char *file;
 {
 	static int first = 1;
 	int n, linenum;
+	int	ghash;
 	char type;
 	register int ser;
 	extern char had_dir, had_standinp;
@@ -437,7 +438,6 @@ char *file;
 	setvbuf(gpkt.p_gout, NULL, _IOFBF, VBUF_SIZE);
 #endif
 	while(readmod(&gpkt)) {
-		chkid(gpkt.p_line,Sflags['i'-'a'], Sflags);
 		if (gpkt.p_flags & PF_NONL)
 			gpkt.p_line[gpkt.p_line_length-1] = '\0';
 		if(fputs(gpkt.p_lineptr, gpkt.p_gout) == EOF)
@@ -456,17 +456,33 @@ char *file;
 	gpkt.p_glnno = 0;
 	gpkt.p_verbose = (HADS) ? 0 : 1;
  	Did_id = number_of_lines = size_of_file = 0;
- 	while (fgets(line,sizeof(line),Gin) != NULL) {
- 	   if (line[strlen(line)-1] == '\n') {
- 	   	number_of_lines++;
- 	   }
- 	   if (Did_id == 0) {
- 	      chkid(line,Sflags['i'-'a'], Sflags);
- 	   }
- 	}
- 	if (stat(gfilename, &Statbuf) == 0) {
- 	   size_of_file = Statbuf.st_size;
- 	}
+
+	gpkt.p_ghash = 0;	/* Reset ghash from previous readmod() calls */
+
+	if (Sflags[EXPANDFLAG - 'a'] && *(Sflags[EXPANDFLAG - 'a']) == '\0') {
+		Did_id++;		/* No need to scan for keywds */
+	}
+	if ((Sflags[ENCODEFLAG - 'a'] == NULL) ||
+	    (strcmp(Sflags[ENCODEFLAG - 'a'],"0") == 0)) {
+		fgetchk(gfilename, &gpkt);
+		number_of_lines = gpkt.p_glines;
+	} else {
+	 	while (fgets(line,sizeof(line),Gin) != NULL) {
+			register int	len = strlen(line);
+
+			gpkt.p_ghash += usum(line, len);
+ 			if (line[len-1] == '\n') {
+ 	   			number_of_lines++;
+			}
+			if (Did_id == 0) {
+				chkid(line,Sflags['i'-'a'], Sflags);
+			}
+		}
+	}
+	gpkt.p_ghash &= 0xFFFF;
+	if (stat(gfilename, &Statbuf) == 0) {
+		size_of_file = Statbuf.st_size;
+	}
 	if (Gin)
 		fclose(Gin);
 	Gin = NULL;
@@ -484,11 +500,6 @@ char *file;
  	   }
  	}
 
-	if ((Sflags[ENCODEFLAG - 'a'] == NULL) ||
-	    (strcmp(Sflags[ENCODEFLAG - 'a'],"0") == 0)) {
-		fgetchk(gfilename, &gpkt);
-	}
-
 	if (!Did_id && !HADQ &&
 	    (!Sflags[EXPANDFLAG - 'a'] ||
 	    *(Sflags[EXPANDFLAG - 'a']))) {
@@ -510,6 +521,7 @@ char *file;
 	*/
 	difflim = 24000;
 	diffloop = 0;
+	ghash = gpkt.p_ghash;		/* Save ghash value */
 	/*CONSTCOND*/
 	while (1) {
 		inserted = deleted = 0;
@@ -518,6 +530,7 @@ char *file;
 		gpkt.p_wrttn = 1;
 		getline(&gpkt);
 		gpkt.p_wrttn = 1;
+		gpkt.p_ghash = ghash;	/* ghash may be destroyed in loop */
         	if (HADF) {
                 	newser = mkdelt(&gpkt, &gpkt.p_reqsid, &gpkt.p_gotsid, 
 				diffloop, orig);
@@ -759,6 +772,9 @@ int orig_nlines;
 		}
 		putcmrs(pkt); /* this routine puts cmrs on the out put file */
 	}
+	if (gpkt.p_flags & PF_V6)
+		sidext_ba(&gpkt, &dt);
+
 	sprintf(str, NOGETTEXT("%c%c "), CTLCHAR, COMMENTS);
 	putline(pkt,str);
 	{
@@ -1293,7 +1309,7 @@ struct	packet	*pkt;
 #ifndef	RECORD_IO
 	char	*p = NULL;	/* Intialize to make gcc quiet */
 	char	*pn =  NULL;
-	char	line[VBUF_SIZE];
+	char	line[VBUF_SIZE+1];
 #else
 	char	line[BUFSIZ];
 	int	search_on = 0;
@@ -1303,6 +1319,8 @@ struct	packet	*pkt;
 	int	warned = 0;
 	char	chkflags = 0;
 	char	lastchar;
+	unsigned int sum = 0;
+	extern char *Sflags[];
 
 	inptr = xfopen(file, O_RDONLY|O_BINARY);
 #ifdef	USE_SETVBUF
@@ -1323,7 +1341,8 @@ struct	packet	*pkt;
 	 * algorithm allows to avoid to do a reverse scan for '\0' from the end
 	 * of the buffer.
 	 */
-	while ((idx = fread(line, 1, sizeof (line), inptr)) > 0) {
+	while ((idx = fread(line, 1, sizeof (line) - 1, inptr)) > 0) {
+		sum += usum(line, idx);
 		if (lastchar == '\n' && line[0] == CTLCHAR) {
 			chkflags |= CK_CTLCHAR;
 			if ((pkt->p_flags & PF_V6) == 0)
@@ -1366,6 +1385,10 @@ struct	packet	*pkt;
 				fatal(SccsError);
 			}
 		}
+		line[idx] = '\0';
+		if (Did_id == 0) {
+			chkid(line, Sflags['i'-'a'], Sflags);
+		}
 	}
 #else	/* !RECORD_IO */
 	while (fgets(line, sizeof (line), inptr) != NULL) {
@@ -1394,6 +1417,7 @@ struct	packet	*pkt;
 		 }
 	      } else {
 		 if (line[idx] == '\0') {
+		    sum += usum(line, idx);
 		    search_on = 1;
 		    lastchar = line[idx-1];
 		    if (lastchar == '\n') {
@@ -1402,11 +1426,17 @@ struct	packet	*pkt;
 		 }
 	      }
 	   }   
+	   if (Did_id == 0) {
+		chkid(line, Sflags['i'-'a'], Sflags);
+	   }
 	   (void)memset(line, '\377', sizeof (line));
 	}
 #endif	/* !RECORD_IO */
 	fclose(inptr);
 
+	pkt->p_ghash = sum & 0xFFFF;
+	pkt->p_glines = nline;
+
 	if (lastchar != '\n')
 		chkflags |= CK_NONL;
 	pkt->p_props |= chkflags;
