@@ -27,10 +27,10 @@
 /*
  * This file contains modifications Copyright 2006-2011 J. Schilling
  *
- * @(#)get.c	1.44 11/08/21 J. Schilling
+ * @(#)get.c	1.45 11/09/03 J. Schilling
  */
 #if defined(sun)
-#pragma ident "@(#)get.c 1.44 11/08/21 J. Schilling"
+#pragma ident "@(#)get.c 1.45 11/09/03 J. Schilling"
 #endif
 /*
  * @(#)get.c 1.59 06/12/12
@@ -528,6 +528,7 @@ char *file;
 #endif
 			}
 		}
+		gpkt.p_ghash = 0;		/* Reset ghash */
 		if (Sflags[ENCODEFLAG - 'a'] &&
 		    (strcmp(Sflags[ENCODEFLAG - 'a'],"1") == 0)) {
 			while (readmod(&gpkt)) {
@@ -543,6 +544,10 @@ char *file;
 					xmsg(gfile, NOGETTEXT("get"));
 			}
 		}
+		if ((gpkt.p_flags & (PF_V6 | PF_V6TAGS)) && gpkt.p_hash)
+			if (gpkt.p_hash[ser] != (gpkt.p_ghash & 0xFFFF))
+				fatal(gettext("corrupted file version (co27)"));
+			
 		if (gpkt.p_gout) {
 			if (fflush(gpkt.p_gout) == EOF)
 				xmsg(gfile, NOGETTEXT("get"));
