@@ -27,10 +27,10 @@
 /*
  * This file contains modifications Copyright 2006-2011 J. Schilling
  *
- * @(#)prs.c	1.31 11/08/21 J. Schilling
+ * @(#)prs.c	1.32 11/09/03 J. Schilling
  */
 #if defined(sun)
-#pragma ident "@(#)prs.c 1.31 11/08/21 J. Schilling"
+#pragma ident "@(#)prs.c 1.32 11/09/03 J. Schilling"
 #endif
 /*
  * @(#)prs.c 1.33 06/12/12
@@ -100,15 +100,16 @@ static char	tempskel[]   =   NOGETTEXT("/tmp/prXXXXXX");	/* used to generate tem
 struct	sid	sid;
 
 static char	untmp[32], uttmp[32], cmtmp[32];
-static char	mrtmp[32], bdtmp[32];
+static char	mrtmp[32], sxtmp[32], bdtmp[32];
 static FILE	*UNiop;
 static FILE	*UTiop;
 static FILE	*CMiop;
 static FILE	*MRiop;
+static FILE	*SXiop;
 static FILE	*BDiop;
 static char	line[BUFSIZ];
 static int	num_files;
-static int	HAD_CM, HAD_MR, HAD_FD, HAD_BD, HAD_UN;
+static int	HAD_CM, HAD_MR, HAD_SX, HAD_FD, HAD_BD, HAD_UN;
 static char	dt_line[BUFSIZ];
 static char	*dataspec = &defline[0];
 static char	iline[BUFSIZ], xline[BUFSIZ], gline[BUFSIZ];
@@ -140,6 +141,7 @@ static void	idsetup __PR((struct sid *gsid, struct packet *pkt, struct deltab *d
 static void	idsetup __PR((struct sid *gsid, struct packet *pkt, time_t *bdate));
 #endif
 static void	putmr __PR((char *cp));
+static void	putsx __PR((char *cp));
 static void	putcom __PR((char *cp));
 static void	read_to __PR((int ch, struct packet *pkt));
 static void	printflags __PR((void));
@@ -525,6 +527,8 @@ register struct packet *pkt;
 			MRiop = maket(mrtmp);
 		if (HAD_CM)
 			CMiop = maket(cmtmp);
+		if (HAD_SX)
+			SXiop = maket(sxtmp);
 		/*
 		Read rest of delta entry. 
 		*/
@@ -546,6 +550,10 @@ register struct packet *pkt;
 					if (HAD_MR)
 						putmr(n);
 					continue;
+				case SIDEXTENS:
+					if (HAD_SX)
+						putsx(n);
+					continue;
 				case COMMENTS:
 					if (HAD_CM)
 						putcom(n);
@@ -564,12 +572,18 @@ register struct packet *pkt;
 							fclose(CMiop);
 						CMiop = NULL;
 					}
+					if (HAD_SX) {
+						if (SXiop)
+							fclose(SXiop);
+						SXiop = NULL;
+					}
 					scanspec(dataspec,&dt,&stats);
 					/*
 					remove temp files for MRs and comments
 					*/
 					unlink(mrtmp);
 					unlink(cmtmp);
+					unlink(sxtmp);
 					break;
 				default:
 					fmterr(pkt);
@@ -790,6 +804,10 @@ struct	stats	*statp;
 				else
 					printf(gettext("no"));
 				break;
+			case 256*'X'+'S':	/* :SX: SID Extensions */
+				if (exists(sxtmp))
+					printfile(sxtmp);
+				break;
 			case 256*'C'+'A':  /* :AC: cmf application field */
 				if((k = Sflags[CMFFLAG - 'a']) == NULL)
 					printf(gettext("none"));
@@ -950,6 +968,7 @@ clean_up()
 	xrm();		      /* remove the 'packet' used for this SCCS file */
 	unlink(mrtmp);		/* remove all temporary files from /tmp */
 	unlink(cmtmp);		/*			"		*/
+	unlink(sxtmp);		/*			"		*/
 	unlink(untmp);		/*			"		*/
 	unlink(uttmp);		/*			"		*/
 	unlink(bdtmp);		/*			"		*/
@@ -1071,6 +1090,7 @@ register struct packet *pkt;
 				case EXCLUDE:
 				case IGNORE:
 				case MRNUM:
+				case SIDEXTENS:
 				case COMMENTS:
 					continue;
 				default:
@@ -1445,6 +1465,31 @@ register char	*cp;
 }
 
 
+/*
+ * This procedure places any SID extensions that are found in the delta table
+ * entry * into the temporary file created for that express purpose
+ * (/tmp/prXXXXXX).
+ */
+static void
+putsx(cp)
+register char	*cp;
+{
+
+	cp += 3;
+
+	if (!(*cp) || (*cp == '\n')) {
+		if (SXiop)
+			fclose(SXiop);
+		SXiop = NULL;
+		return;
+	}
+
+	if (fputs(cp, SXiop) == EOF) {
+		xmsg(sxtmp, NOGETTEXT("putsx"));
+	}
+}
+
+
 /*
  * This procedure is the same as "putmr" except it is used for the comment
  * section of the delta table entries.
@@ -1557,6 +1602,8 @@ register char *p;
 		HAD_CM = 1;
 	if (sccs_index(p,NOGETTEXT(":MR:")) != -1)	/* check for MR keyword */
 		HAD_MR = 1;
+	if (sccs_index(p,NOGETTEXT(":SX:")) != -1)	/* check for SX keyword */
+		HAD_SX = 1;
 	if (sccs_index(p,NOGETTEXT(":UN:")) != -1)	/* check for User name keyword */
 		HAD_UN = 1;
 	if (sccs_index(p,NOGETTEXT(":FD:")) != -1)	/* check for descriptive text kyword */
