@@ -27,10 +27,10 @@
 /*
  * This file contains modifications Copyright 2006-2011 J. Schilling
  *
- * @(#)val.c	1.28 11/08/22 J. Schilling
+ * @(#)val.c	1.29 11/09/03 J. Schilling
  */
 #if defined(sun)
-#pragma ident "@(#)val.c 1.28 11/08/22 J. Schilling"
+#pragma ident "@(#)val.c 1.29 11/09/03 J. Schilling"
 #endif
 /*
  * @(#)val.c 1.22 06/12/12
@@ -1071,6 +1071,9 @@ register char *d_sid;
 				case EXCLUDE:
 				case IGNORE:
 					continue;
+				case SIDEXTENS:
+					if (pkt->p_flags & PF_V6)
+						continue;
 				default:
 					return(1);
 				}
