@@ -28,12 +28,12 @@
 /*
  * This file contains modifications Copyright 2006-2011 J. Schilling
  *
- * @(#)defines.h	1.47 11/08/22 J. Schilling
+ * @(#)defines.h	1.51 11/09/02 J. Schilling
  */
 #ifndef	_HDR_DEFINES_H
 #define	_HDR_DEFINES_H
 #if defined(sun)
-#pragma ident "@(#)defines.h 1.47 11/08/22 J. Schilling"
+#pragma ident "@(#)defines.h 1.51 11/09/02 J. Schilling"
 #endif
 /*
  * @(#)defines.h 1.21 06/12/12
@@ -261,6 +261,10 @@ typedef struct dtime {
 #define	DT_LSTRSIZE	20	/* "2011/08/18 10:54:30"		*/
 #define	DT_ZSTRSIZE	35	/* "2011/08/18 10:54:30.123456789+0200"	*/
 
+/*
+ * An array of struct apply[maxser+1] is allocated by dodelt() and assigned to
+ * pkt->p_apply
+ */
 struct apply {
 	char	a_inline;	/* in the line of normally applied deltas */
 	char	a_code;		/* APPLY, NOAPPLY or SX_EMPTY */
@@ -321,6 +325,10 @@ struct	ixg {
 	int	i_ser[1];
 };
 
+/*
+ * An array of struct idel[maxser+1] is allocated by dodelt() and assigned to
+ * pkt->p_idel
+ */
 struct	idel {
 	struct	sid	i_sid;
 	struct	ixg	*i_ixg;
@@ -370,11 +378,16 @@ struct packet {
 	int	p_ihash;	/* initial (input) hash */
 	int	p_chash;	/* current (input) hash */
 	int	p_uchash;	/* current unsigned (input) hash */
+	int	p_clhash;	/* current (input) line hash */
+	int	p_uclhash;	/* current unsigned (input) line hash */
 	int	p_nhash;	/* new (output) hash */
+	int	p_ghash;	/* current gfile hash */
+	int	p_glines;	/* number of lines in current gfile */
 	int	p_glnno;	/* line number of current gfile line */
 	int	p_slnno;	/* line number of current input line */
 	char	p_wrttn;	/* written flag (!0 = written) */
 	char	p_keep;		/* keep switch for readmod() */
+	uint16_t *p_hash;	/* ptr to array of checksums */
 	struct	apply *p_apply;	/* ptr to apply array */
 	struct	queue *p_q;	/* ptr to control queue */
 	FILE	*p_iop;		/* input file */
@@ -407,9 +420,10 @@ struct packet {
  * If we set the flag, we need to carefully compensate the systematic error
  * introduced by this hack.
  */
-#define	PF_GMT	1		/* Use GMT conversion			  */
-#define	PF_V6	2		/* Support SCCS V6 features		  */
-#define	PF_NONL	4		/* This line has no newline		  */
+#define	PF_GMT		1	/* Use GMT conversion			  */
+#define	PF_V6		2	/* Support SCCS V6 features		  */
+#define	PF_V6TAGS	4	/* SCCS V6 features found in hist file	  */
+#define	PF_NONL		8	/* This line has no newline		  */
 
 /*
  * Flags to collect reasons for non-Text files also used in p_props
@@ -455,6 +469,9 @@ extern	void	finduser __PR((struct packet *));
 extern	void	permiss	__PR((struct packet *));
 extern	char*	sid_ab	__PR((char *, struct sid *));
 extern	char*	sid_ba	__PR((struct sid *, char *));
+extern	void	sidext_ab __PR((struct packet *, struct deltab *, char *));
+extern	void	sidext_v4compat_ab __PR((struct packet *, struct deltab *));
+extern	void	sidext_ba __PR((struct packet *, struct deltab *));
 extern	char*	omit_sid __PR((char *));
 extern	int	date_ab	__PR((char *, time_t *, int flags));
 extern	int	date_abz __PR((char *, dtime_t *, int flags));
@@ -511,12 +528,15 @@ extern	void	get_Del_Date_time __PR((char *, struct deltab *, struct packet *, st
 extern	char*	stalloc	__PR((unsigned int));
 extern	int	mosize	__PR((int y, int t));
 extern	int	gN	__PR((char *str, char **next, int num, int *digits, int *chars));
+extern	int	gNp	__PR((char *str, char **next, int num, int *digits, int *chars));
 extern	int	gns	__PR((char *str, char **next));
 extern	int	gtz	__PR((char *str, char **next));
 extern	void	xtzset	__PR((void));
 extern	void	dtime	__PR((dtime_t *));
 extern	void	time2dt	__PR((dtime_t *, time_t, int));
 extern	time_t	gmtoff	__PR((time_t));
+extern	int		ssum __PR((char *, int));
+extern	unsigned int	usum __PR((char *, int));
 
 /*
  Declares for external functions in lib/mpwlib
