@@ -27,10 +27,10 @@
 /*
  * This file contains modifications Copyright 2006-2011 J. Schilling
  *
- * @(#)dodelt.c	1.9 11/08/21 J. Schilling
+ * @(#)dodelt.c	1.11 11/09/02 J. Schilling
  */
 #if defined(sun)
-#pragma ident "@(#)dodelt.c 1.9 11/08/21 J. Schilling"
+#pragma ident "@(#)dodelt.c 1.11 11/09/02 J. Schilling"
 #endif
 /*
  * @(#)dodelt.c 1.8 06/12/12
@@ -101,8 +101,17 @@ char type;
 				CDid_mrs = 0;
 				for (p = pkt->p_line; *p && *p != 'D'; p++)
 					;
-				if (*p)
+				if (*p) {
+					/*
+					 * Also correct saved line hash, used
+					 * for putline() optimization.
+					 */
+					pkt->p_clhash -= 'D';
+					pkt->p_uclhash -= 'D';
+					pkt->p_clhash += type;
+					pkt->p_uclhash += type;
 					*p = type;
+				}
 			}
 			else
 				First_esc = founddel = First_cmt = 0;
@@ -123,6 +132,8 @@ char type;
 				case EDELTAB:
 					break;
 				case COMMENTS:
+					if (pkt->p_line[2] == '_')
+						sidext_v4compat_ab(pkt, &dt);
 				case MRNUM:
 					if (founddel)
 					{
@@ -133,6 +144,12 @@ char type;
 						}
 					}
 				continue;
+
+				case SIDEXTENS:
+					if (pkt->p_flags & PF_V6) {
+						sidext_ab(pkt, &dt, &pkt->p_line[2]);
+						continue;
+					}
 				default:
 					fmterr(pkt);
 				/*FALLTHRU*/
