@@ -27,10 +27,10 @@
 /*
  * This file contains modifications Copyright 2006-2011 J. Schilling
  *
- * @(#)putline.c	1.13 11/08/22 J. Schilling
+ * @(#)putline.c	1.14 11/08/29 J. Schilling
  */
 #if defined(sun)
-#pragma ident "@(#)putline.c 1.13 11/08/22 J. Schilling"
+#pragma ident "@(#)putline.c 1.14 11/08/29 J. Schilling"
 #endif
 /*
  * @(#)putline.c 1.13 06/12/12
@@ -152,16 +152,35 @@ char *newline;
 		if(fputs((const char *)p,Xiop)==EOF)
 			FAILPUT;
 		if (Xcreate) {
-			register int	hash = 0;
-
-			if(signed_chksum) {
-				while (*p)
-					hash += *p++;
+			if (newline) {
+				register int	hash = 0;
+	
+				if(signed_chksum) {
+					while (*p)
+						hash += *p++;
+				} else {
+					while (*p)
+						hash += *u_p++;
+				}
+				pkt->p_nhash += hash;
 			} else {
-				while (*p)
-					hash += *u_p++;
+#ifdef	ALLOW_MODIFIED_LINE
+				if(signed_chksum)
+					pkt->p_nhash += ssum((char *)p,
+							    pkt->p_line_length);
+				else
+					pkt->p_nhash += usum((char *)p,
+							    pkt->p_line_length);
+#else
+				/*
+				 * Use hash from getline()
+				 */
+				if(signed_chksum)
+					pkt->p_nhash += pkt->p_clhash;
+				else
+					pkt->p_nhash += pkt->p_uclhash;
+#endif
 			}
-			pkt->p_nhash += hash;
 		}
 	}
 	Xcreate = 1;
